==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/getvreg.sql <==
set @@character_set_client = 'utf8';

delimiter //
DROP FUNCTION IF EXISTS getvreg//
create function getvreg(rx varchar(2000)) returns varchar(2000)
  deterministic
  sql security invoker
  begin
    declare r, rr, r1, r2 varchar(2000);
    declare b1, b2, b integer;

    if rx = ''
     then
      return '';
    end if;

    set r = replace(replace(replace(replace(replace(replace(mid(rx, 2, char_length(rx)-2), '\\\\', 0x01), '\\(', 0x02), '\\)', 0x03), '\\[', 0x04), '\\]', 0x05), '\\.', 0x06);

    set b1 = regexp_instr(r, '\\(.*\\)');
    while b1 > 0 do
      set b2 = locate(')', r, b1);
      set rr = substr(r, b1 + 1, b2 - b1 - 1);
      set r1 = substring_index(rr, '|', 1);
      set b = locate('-', r1);
      if b > 0 then
        set r1 = replace(left(r1, b-1), '[', '');
      end if;
      set r2 = replace(replace(substring_index(rr, '|', -1), '[0-', ''), ']', '');
      set r = concat(left(r, b1 - 1), '{', r1, '-', r2, '}', substr(r, b2 + 1));
      set b1 = regexp_instr(r, '\\(.*\\)');
    end while;
    set r = replace(replace(r, '[', '{'), ']', '}');

    set r = replace(replace(replace(replace(replace(replace(r, 0x02, '('), 0x03, ')'), 0x04, '['), 0x05, ']'), '$|^', ',!'), '\\|', '|');
    set r = replace(replace(replace(replace(replace(replace(r, '\\+', '+'), '\\$', '$'), '\\^', '^'), '\\?', 0x02), '\\*', 0x03), '.*', '*');

    return concat('!', replace(replace(replace(replace(replace(r, '.', '?'), 0x02, '*?'), 0x06, '.'), 0x03, '**'), 0x01, '\\'));

  end//

GRANT EXECUTE on FUNCTION getvreg
  to logginglesen@'localhost', loggingtest@'localhost', loggingadmin@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/getvreg.sql <==
-- getvreg.sql
--
-- function getvreg(rx) returns varchar
-- rx: regexp to exclude - rx must be empty or elements between "|" must start with "^" and end with "$"
-- return: ULS Wildcardstring for excludes
--
-- see genreg

set @@character_set_client = 'utf8';

delimiter //
DROP FUNCTION IF EXISTS getvreg//
create function getvreg(rx varchar(2000)) returns varchar(2000)
  deterministic
  sql security invoker
  begin
    declare r, rr, r1, r2 varchar(2000);
    declare b1, b2, b integer;

    if rx = ''
     then
      return '';
    end if;

    set r = replace(replace(replace(replace(replace(replace(mid(rx, 2, char_length(rx)-2), '\\\\', 0x01), '\\(', 0x02), '\\)', 0x03), '\\[', 0x04), '\\]', 0x05), '\\.', 0x06);

    set b1 = regexp_instr(r, '\\(.*\\)');
    while b1 > 0 do
      set b2 = locate(')', r, b1);
      set rr = substr(r, b1 + 1, b2 - b1 - 1);
      set r1 = substring_index(rr, '|', 1);
      set b = locate('-', r1);
      if b > 0 then
        set r1 = replace(left(r1, b-1), '[', '');
      end if;
      set r2 = replace(replace(substring_index(rr, '|', -1), '[0-', ''), ']', '');
      set r = concat(left(r, b1 - 1), '{', r1, '-', r2, '}', substr(r, b2 + 1));
      set b1 = regexp_instr(r, '\\(.*\\)');
    end while;
    set r = replace(replace(r, '[', '{'), ']', '}');

    set r = replace(replace(replace(replace(replace(replace(replace(r, ',', '\\,'), 0x02, '('), 0x03, ')'), 0x04, '['), 0x05, ']'), '$|^', ',!'), '\\|', '|');

    return concat('!', replace(replace(replace(replace(replace(replace(replace(r, '\\+', '+'), '\\$', '$'), '\\^', '^'), '.*', '*'), '.', '?'), 0x06, '.'), 0x01, '\\\\'));

  end//

GRANT EXECUTE on FUNCTION getvreg
  to logginglesen@'localhost', loggingtest@'localhost', loggingadmin@'localhost'//
